#!/usr/bin/env python3
permitted = "0123456789+-/*= "

def cli():
    print("""
    ######## Calculator ########
    #    Permitted operators   #
    #            +             #
    #            -             #
    #            *             #
    #            /             #
    ############################
    """)

    while True:
        data = input("Calculate: ")
        for s in data:
            if s not in permitted:
                quit()

        res = eval(data)

        print(res)



from distutils.core import setup
setup(
  name = 'hes',
  packages = ['hes'],
  version = '0.4',
  description = 'A cute calculator',
  author = 'Cagatay CALI',
  author_email = 'cagataycali@icloud.com',
  url = 'https://github.com/cagataycali/hes',
  download_url = 'https://github.com/cagataycali/hes/archive/0.4.tar.gz',
  keywords = ['cute', 'calculator'],
  classifiers = [],
  entry_points='''
        [console_scripts]
        hes=hes/hes:cli
    ''',
)
